pub struct Event {
pub account: Option<String>,
pub api_version: Option<ApiVersion>,
pub created: Timestamp,
pub data: EventData,
pub id: EventId,
pub livemode: bool,
pub object: EventObjectType,
pub pending_webhooks: i64,
pub request: Option<NotificationEventRequest>,
pub type_: EventType,
}Fields
account: Option<String>The connected account that originated the event.
api_version: Option<ApiVersion>The Stripe API version used to render data.
Note: This property is populated only for events on or after October 31, 2014.
created: TimestampTime at which the object was created.
Measured in seconds since the Unix epoch.
data: EventDataid: EventIdUnique identifier for the object.
livemode: boolHas the value true if the object exists in live mode or the value false if the object exists in test mode.
object: EventObjectTypeString representing the object’s type. Always has the value “event”.
pending_webhooks: i64Number of webhooks that have yet to be successfully delivered (i.e., to return a 20x response) to the URLs you’ve specified.
request: Option<NotificationEventRequest>Information on the API request that instigated the event.
type_: EventTypeDescription of the event (e.g., invoice.created or charge.refunded).